\name{acp}
\alias{acp}
\alias{pca}
\alias{print.acp}

\title{Principal component analysis}
\description{Principal component analysis / Analyse en composantes principales}
\usage{
acp(x,center=TRUE,reduce=TRUE)
pca(x,center=TRUE,reduce=TRUE)
print.acp(x, ...) 
}

\arguments{
\item{x}{Matrix  / data frame}
\item{center}{a logical value indicating whether we center data}
\item{reduce}{a logical value indicating whether we "reduce" data i.e. 
divide each column by standard deviation}
\item{\dots}{arguments to be passed to or from other methods.}
}




\value{
  An object of class \bold{acp} 
  The object is a list with components:

  \item{sdev}{the standard deviations of the principal components.}
  \item{loadings}{the matrix of variable loadings (i.e., a matrix
    whose columns contain the eigenvectors).  This is of class
    \code{"loadings"}: see \code{\link[mva]{loadings}} for its \code{print}
    method.}
  \item{scores}{if \code{scores = TRUE}, the scores of the supplied
    data on the principal components.}
  \item{eig}{Eigen values}
}

\references{
  A. Carlier
  Analyse des donnes Multidimensionnelles
  \url{http://www.lsp.ups-tlse.fr/Carlier/enseignement.html}
}


\examples{
data(lubisch)
lubisch <- lubisch[,-c(1,8)]
p <- acp(lubisch)
plot(p)
}
\keyword{multivariate}

\author{Antoine Lucas, \url{http://genopole.toulouse.inra.fr/~lucas/amap}}
\seealso{\link{plot.acp},\link{acpgen}, \link[mva]{princomp} }

\eof
\name{acpgen}
\alias{acpgen}
\alias{K}
\alias{W}
\alias{WsansC}


\title{Generalised principal component analysis}
\description{Generalised principal component analysis / Analyse en composantes principales gnralise}

\usage{
acpgen(x,h1,h2,center=TRUE,reduce=TRUE,kernel="gaussien")
K(u,kernel="gaussien")
W(x,h,D=NULL,kernel="gaussien")
WsansC(x,h,D=NULL,kernel="gaussien")
}

\arguments{
\item{x}{Matrix  / data frame}
\item{h}{Scalar: bandwidth of the Kernel}
\item{h1}{Scalar: bandwidth of the Kernel for W}
\item{h2}{Scalar: bandwidth of the Kernel for U}
\item{kernel}{The kernel used. This must be one of '"gaussien"', 
'"quartic"', '"triweight"', '"epanechikov"' , 
'"cosinus"' or '"uniform"' } 
\item{center}{A logical value indicating whether we center data}
\item{reduce}{A logical value indicating whether we "reduce" data i.e. 
divide each column by standard deviation}
\item{D}{A product scalar matrix / une matrice de produit scalaire}
\item{u}{Vector}
}

\details{
\code{acpgen} compute generalised pca. i.e. spectral analysis of 
\eqn{U_n . W_n^{-1}}{Un / Wn}, and project \eqn{X_i}{Xi} with
\eqn{W_n^{-1}}{1/Wn} on the principal vector sub-spaces.

\eqn{X_i}{Xi} a column vector of \eqn{p} variables of individu  \eqn{i} 
(input data)

\code{W} compute estimation of noise in the variance. 
\deqn{W_n=\frac{\sum_{i=1}^{n-1}\sum_{j=i+1}^{n}K(||X_i-X_j||_{V_n^{-1}}/h)(X_i-X_j)(X_i-X_j)'}{\sum_{i=1}^{n-1}\sum_{j=i+1}^{n}K(||X_i-X_j||_{V_n^{-1}}/h)}}{W: see latex doc}


with \eqn{V_n}{Vn} variance estimation;

\code{U} compute robust variance. \eqn{U_n^{-1} = S_n^{-1} - 1/h V_n^{-1}}{1/Un
 = 1/Sn - 1 / (h Vn)}


\deqn{S_n=\frac{\sum_{i=1}^{n}K(||X_i||_{V_n^{-1}}/h)(X_i-\mu_n)(X_i-\mu_n)'}{\sum_{i=1}^nK(||X_i||_{V_n^{-1}}/h)}}{S: see latex doc}

with \eqn{\mu_n} estimator of the mean.

%\eqn{\delta=K(|| X_i-X_j||)} with K: a kernel.

\code{K} compute   kernel, i.e.

gaussien: \deqn{\frac{1}{\sqrt{2\pi}}  e^{-u^2/2}}{
               1/sqrt(2pi)  exp(-u^2/2)}

quartic: \deqn{\frac{15}{16}(1-u^2)^2 I_{|u|\leq 1}  }{
              15/16 (1-u^2)^2  if |u| < 1}

triweight: \deqn{\frac{35}{32}(1-u^2)^3 I_{|u|\leq 1}  }{
              35/32 (1-u^2)^3  if |u| < 1}

epanechikov: \deqn{\frac{3}{4}(1-u^2) I_{|u|\leq 1}  }{
              3/4 (1-u^2)  if |u| < 1}


cosinus: \deqn{\frac{\pi}{4}\cos(\frac{\pi}{2}u) I_{|u|\leq 1}  }{
               pi/4 cos (u * pi/2)  if |u| < 1}

}

\value{
  An object of class \bold{acp} 
  The object is a list with components:

  \item{sdev}{the standard deviations of the principal components.}
  \item{loadings}{the matrix of variable loadings (i.e., a matrix
    whose columns contain the eigenvectors).  This is of class
    \code{"loadings"}: see \code{\link[mva]{loadings}} for its \code{print}
    method.}
  \item{scores}{if \code{scores = TRUE}, the scores of the supplied
    data on the principal components.}
  \item{eig}{Eigen values}
}

\references{
  H. Caussinus, S. Hakam, A. Ruiz-Gazen
  Projections rvlatrices contrles: groupements et structures
  diverses.
  2002, to appear in Rev. Statist. Appli.
}

\examples{
data(lubisch)
lubisch <- lubisch[,-c(1,8)]
p <- acpgen(lubisch,h1=1,h2=1/sqrt(2))
plot(p,main='ACP robuste des individus')

# See difference with acp

p <- acp(lubisch)
plot(p)

# Other Data
.Random.seed <- c(1,  416884367 ,1051235439)
n <- 100   # Number of observations
m <- 0     # Mean of 1 group
temp <- cbind(rnorm(n,m,1),rnorm(n,0,10))
m <- 10
mat <- rbind(temp,cbind(rnorm(n,m,1),rnorm(n,0,10)))
mat <- scale(mat,TRUE,TRUE)
rm (m,n,temp) 

}
\keyword{multivariate}

\author{Antoine Lucas, \url{http://genopole.toulouse.inra.fr/~lucas/amap}}
\seealso{\link{acp} \link{acprob} \link[mva]{princomp} }




\eof
\name{acprob}
\alias{acprob}
\title{Robust principal component analysis}
\description{Robust principal component analysis / Analyse en composantes principales robuste}

\usage{
acprob(x,h,center=TRUE,reduce=TRUE,kernel="gaussien")
}

\arguments{
\item{x}{Matrix  / data frame}
\item{h}{Scalar: bandwidth of the Kernel}
\item{kernel}{The kernel used. This must be one of '"gaussien"', 
'"quartic"', '"triweight"', '"epanechikov"' , 
'"cosinus"' or '"uniform"' } 
\item{center}{A logical value indicating whether we center data}
\item{reduce}{A logical value indicating whether we "reduce" data i.e. 
divide each column by standard deviation}
}


\details{
  \code{acpgen}  compute robust pca. i.e. spectral analysis of a robust
  variance instead of usual variance. Robust variance: see
  \code{\link[amap]{varrob}}
  }

  \value{
  An object of class \bold{acp} 
  The object is a list with components:

  \item{sdev}{the standard deviations of the principal components.}
  \item{loadings}{the matrix of variable loadings (i.e., a matrix
    whose columns contain the eigenvectors).  This is of class
    \code{"loadings"}: see \code{\link[mva]{loadings}} for its \code{print}
    method.}
  \item{scores}{if \code{scores = TRUE}, the scores of the supplied
    data on the principal components.}
  \item{eig}{Eigen values}
}
\keyword{multivariate}

\author{Antoine Lucas, \url{http://genopole.toulouse.inra.fr/~lucas/amap}}
\seealso{\link{acp} \link[mva]{princomp} }

\eof
\name{dist}
\title{Distance Matrix Computation}
\usage{
dist(x, method = "euclidean", diag = FALSE, upper = FALSE)

print.dist(x, diag = NULL, upper = NULL, \dots)
as.matrix.dist(x)
as.dist(m, diag = FALSE, upper = FALSE)
}
\alias{dist}
\alias{print.dist}
\alias{format.dist}
\alias{as.matrix.dist}
\alias{names.dist}
\alias{names<-.dist}
\alias{as.dist}
\arguments{
  \item{x}{numeric matrix or (data frame).  Distances between the rows of
    \code{x} will be computed.}
  \item{method}{the distance measure to be used. This must be one of
    \code{"euclidean"}, \code{"maximum"}, \code{"manhattan"},
    \code{"canberra"} or \code{"binary"} \code{"pearson"} or
    \code{"correlation"}.
    Any unambiguous substring can be given.}
  \item{diag}{logical value indicating whether the diagonal of the
    distance matrix should be printed by \code{print.dist}.}
  \item{upper}{logical value indicating whether the upper triangle of the
    distance matrix should be printed by \code{print.dist}.}
  \item{m}{A matrix of distances to be converted to a \code{"dist"}
    object (only the lower triangle is used, the rest is ignored).}
  \item{\dots}{further arguments, passed to the (next) \code{print} method.}
}
\description{
  This function computes and returns the distance matrix computed by
  using the specified distance measure to compute the distances between
  the rows of a data matrix.
}
\details{
  Available distance measures are (written for two vectors \eqn{x} and
  \eqn{y}):
  \describe{
    \item{\code{euclidean}:}{Usual square distance between the two
      vectors (2 norm).}

    \item{\code{maximum}:}{Maximum distance between two components of \eqn{x}
      and \eqn{y} (supremum norm)}

    \item{\code{manhattan}:}{Absolute distance between the two vectors
      (1 norm).}

    \item{\code{canberra}:}{\eqn{\sum_i |x_i - y_i| / |x_i + y_i|}{%
	sum(|x_i - y_i| / |x_i + y_i|)}.  Terms with zero numerator and
      denominator are omitted from the sum and treated as if the values
      were missing.
    }

    \item{\code{binary}:}{(aka \emph{asymmetric binary}): The vectors
      are regarded as binary bits, so non-zero elements are `on' and zero
      elements are `off'.  The distance is the \emph{proportion} of
      bits in which only one is on amongst those in which at least one is on.}

    \item{\code{pearson}:}{Also named "not centered Pearson"
      \eqn{1 - \frac{\sum_i x_i y_i}{\sum_i x_i^2 %
	  + \sum_i y_i^2}}{%
	sum(x_i y_i) / [sum(x_i^2) sum(y_i^2)]}.
    }

    \item{\code{correlation}:}{Also named "Centered Pearson"
      \eqn{1 - corr(x,y)}.  
    }
  }

  Missing values are allowed, and are excluded from all computations
  involving the rows within which they occur.  If some columns are
  excluded in calculating a Euclidean, Manhattan or Canberra distance,
  the sum is scaled up proportionally to the number of columns used.
  If all pairs are excluded when calculating a particular distance,
  the value is \code{NA}.

  The functions \code{as.matrix.dist()} and \code{as.dist()} can be used
  for conversion between objects of class \code{"dist"} and conventional
  distance matrices and vice versa.
}
\value{
  An object of class \code{"dist"}.

  The lower triangle of the distance matrix stored by columns in a
  vector, say \code{do}. If \code{n} is the number of
  observations, i.e., \code{n <- attr(do, "Size")}, then
  for \eqn{i < j <= n}, the dissimilarity between (row) i and j is
  \code{do[n*(i-1) - i*(i-1)/2 + j-i]}.
  The length of the vector is \eqn{n*(n-1)/2}, i.e., of order \eqn{n^2}.

  The object has the following attributes (besides \code{"class"} equal
  to \code{"dist"}):
  \item{Size}{integer, the number of observations in the dataset.}
  \item{Labels}{optionally, contains the labels, if any, of the
    observations of the dataset.}
  \item{Diag, Upper}{logicals corresponding to the arguments \code{diag}
    and \code{upper} above, specifying how the object should be printed.}
  \item{call}{optionally, the \code{\link{call}} used to create the
    object.}
  \item{methods}{optionally, the distance method used; resulting form
    \code{\link{dist}()}, the (\code{\link{match.arg}()}ed) \code{method}
    argument.}
}
\references{
  Mardia, K. V., Kent, J. T. and Bibby, J. M. (1979)
  \emph{Multivariate Analysis.} London: Academic Press.
}
\seealso{
  \code{\link[cluster]{daisy}} in the \file{cluster} package with more
  possibilities in the case of \emph{mixed} (contiuous / categorical)
  variables.
 \code{\link[mva]{dist}}  \code{\link{hclust}}.
}
\examples{
x <- matrix(rnorm(100), nrow=5)
dist(x)
dist(x, diag = TRUE)
dist(x, upper = TRUE)
m <- as.matrix(dist(x))
d <- as.dist(m)
stopifnot(d == dist(x))
names(d) <- LETTERS[1:5]
print(d, digits = 3)

## example of binary and canberra distances.
x <- c(0, 0, 1, 1, 1, 1)
y <- c(1, 0, 1, 1, 0, 1)
dist(rbind(x,y), method="binary")
## answer 0.4 = 2/5
dist(rbind(x,y), method="canberra")
## answer 2 * (6/5)
}
\keyword{multivariate}
\keyword{cluster}

\eof
\name{hclust}
\title{Hierarchical Clustering}
\alias{hclust}
\alias{plot.hclust}
\alias{plclust}
\alias{print.hclust}
\description{
  Hierarchical cluster analysis on a set of dissimilarities and
  methods for analyzing it.
}
\usage{
hclust(d, method = "complete", members=NULL)

plot.hclust(x, labels = NULL, hang = 0.1,
            axes = TRUE, frame.plot = FALSE, ann = TRUE,
            main = "Cluster Dendrogram",
            sub = NULL, xlab = NULL, ylab = "Height", \dots)

plclust(tree, hang = 0.1, unit = FALSE, level = FALSE, hmin = 0,
        square = TRUE, labels = NULL, plot. = TRUE,
        axes = TRUE, frame.plot = FALSE, ann = TRUE,
        main = "", sub = NULL, xlab = NULL, ylab = "Height")
}
\arguments{
  \item{d}{a dissimilarity structure as produced by \code{dist}.}

  \item{method}{the agglomeration method to be used. This should
    be (an unambiguous abbreviation of) one of
    \code{"ward"}, \code{"single"}, \code{"complete"},
    \code{"average"}, \code{"mcquitty"}, \code{"median"} or
    \code{"centroid"}.}

  \item{members}{\code{NULL} or a vector with length size of \code{d}.}

  \item{x,tree}{an object of the type produced by \code{hclust}.}

  \item{hang}{The fraction of the plot height by which labels should hang
    below the rest of the plot.
    A negative value will cause the labels to hang down from 0.}

  \item{labels}{A character vector of labels for the leaves of the
    tree. By default the row names or row numbers of the original data are
    used. If \code{labels=FALSE} no labels at all are plotted.}

  \item{axes, frame.plot, ann}{logical flags as in \code{\link{plot.default}}.}
  \item{main, sub, xlab, ylab}{character strings for
    \code{\link{title}}.  \code{sub} and \code{xlab} have a non-NULL
    default when there's a \code{tree$call}.}
  \item{\dots}{Further graphical arguments.}

  \item{unit, level, hmin, square, plot.}{as yet unimplemented arguments of
    \code{plclust} for S-plus compatibility.}
}
\value{
  An object of class \bold{hclust} which describes the
  tree produced by the clustering process.
  The object is a list with components:
  \item{merge}{an \eqn{n-1} by 2 matrix.
    Row \eqn{i} of \code{merge} describes the merging of clusters
    at step \eqn{i} of the clustering.
    If an element \eqn{j} in the row is negative,
    then observation \eqn{-j} was merged at this stage.
    If \eqn{j} is positive then the merge
    was with the cluster formed at the (earlier) stage \eqn{j}
    of the algorithm.
    Thus negative entries in \code{merge} indicate agglomerations
    of singletons, and positive entries indicate agglomerations
    of non-singletons.}

  \item{height}{a set of \eqn{n-1} non-decreasing real values.
    The clustering \emph{height}: that is, the value of
    the criterion associated with the clustering
    \code{method} for the particular agglomeration.}

  \item{order}{a vector giving the permutation of the original
    observations suitable for plotting, in the sense that a cluster
    plot using this ordering and matrix \code{merge} will not have
    crossings of the branches.}

  \item{labels}{labels for each of the objects being clustered.}

  \item{call}{the call which produced the result.}

  \item{method}{the cluster method that has been used.}

  \item{dist.method}{the distance that has been used to create \code{d}
    (only returned if the distance object has a \code{"method"}
    attribute).}

  There is a \code{\link{print}} and a \code{\link{plot}} method for
  \code{hclust} objects.
  The \code{plclust()} function is basically the same as the plot method,
  \code{plot.hclust}, primarily for back compatibility with S-plus. Its
  extra arguments are not yet implemented.
}
\details{
  This function performs a hierarchical cluster analysis
  using a set of dissimilarities for the \eqn{n} objects being
  clustered.  Initially, each object is assigned to its own
  cluster and then the algorithm proceeds iteratively,
  at each stage joining the two most similar clusters,
  continuing until there is just a single cluster.
  At each stage distances between clusters are recomputed
  by the Lance--Williams dissimilarity update formula
  according to the particular clustering method being used.

  A number of different clustering methods are provided.
  \emph{Ward's} minimum variance method aims at finding compact,
  spherical clusters.  The \emph{complete linkage} method finds
  similar clusters. The \emph{single linkage} method
  (which is closely related to the minimal spanning tree)
  adopts a `friends of friends' clustering strategy.
  The other methods can be regarded as aiming
  for clusters with characteristics somewhere between
  the single and complete link methods.

  If \code{members!=NULL}, then \code{d} is taken to be a
  dissimilarity matrix between clusters instead of dissimilarities
  between singletons and \code{members} gives the number of observations
  per cluster. This way the hierarchical cluster algorithm can be ``started
  in the middle of the dendrogram'', e.g., in order to reconstruct the
  part of the tree above a cut (see examples). Dissimilarities between
  clusters can be efficiently computed (i.e., without \code{hclust}
  itself) only for a limited number of distance/linkage combinations,
  the simplest one being squared Euclidean distance and centroid
  linkage. In this case the dissimilarities between the clusters are
  the squared Euclidean distances between cluster means.

  In hierarchical cluster displays, a decision is needed at each merge to
  specify which subtree should go on the left and which on the right.
  Since, for \eqn{n} observations there are \eqn{n-1} merges,
  there are \eqn{2^{(n-1)}} possible orderings for the leaves
  in a cluster tree, or dendrogram.
  The algorithm used in \code{hclust} is to order the subtree so that
  the tighter cluster is on the left (the last, i.e. most recent,
  merge of the left subtree is at a lower value than the last
  merge of the right subtree).
  Single observations are the tightest clusters possible,
  and merges involving two observations place them in order by their
  observation sequence number.

  More details on agglomeration methods between groups \eqn{A} and
  \eqn{B}:

  \describe{
  \item{\code{Ward}}{ can be calculated recursively:
  \deqn{d(AB,C) = \frac{(n_A+n_C) d(A,C) + (n_B+n_C) d(B,C) - 
      n_C d(A,B)}{n_A+n_B+n_C}}{d(AB,C) = [(n_A+n_C) d(A,C) +
     (n_B+n_C) d(B,C) - n_C d(A,B)]/(n_A+n_B+n_C)}}

   \item{\code{Single}:}{\deqn{d(A,B) = \min_{i\in A,j\in B}d_{ij}
   }{d(A,B) = minimum of all distances between A and B}}
   
   \item{\code{Complete}:}{ \deqn{d(A,B) = \sup_{i\in A,j\in B}d_{ij}
   }{d(A,B) = maximum of all distances between A and B}}
   
   \item{\code{Average}:}{ \deqn{d(A,B) = \frac 1{card(A) card(B)}
     \sum_{i\in A,j\in B}d_{ij}}{d(A,B) =
     mean of all distances between A and B}}
   
   \item{\code{Mcquitty}}{, can be calculated recursively
   \deqn{d(AB,C) = \frac12 d(A,C) + \frac12 d(B,C)}{d(AB,C)
     =0.5 d(A,C) + 0.5 D(B,C)}}

   \item{\code{Median}}{(Gower's method), can be calculated recursively
   \deqn{d(AB,C) = \frac12 d(A,C) + \frac12 d(B,C) -
     \frac14 d(A,B)}{0.5 d(A,C) + 0.5 D(B,C) - 0.25 D(A,B)}}
   
   \item{\code{Centroid}}{ can be calculated recursively:
   \deqn{d(AB,C) = \frac{n_A d(A,C) + n_B d(B,C) - 
       \frac{n_A n_B}{n_A+n_B} d(A,B)}{n_A+n_B}}{d(AB,C) =
     [nA d(A,C) + nB d(B,C) - nA nB / (nA + nB) d(A,B)] / (nA + nB)}}
 }
}
\references{
  Everitt, B. (1974).
  \emph{Cluster Analysis}.
  London: Heinemann Educ. Books.

  Hartigan, J. A. (1975).
  \emph{Clustering  Algorithms}.
  New York: Wiley.

  Sneath, P. H. A. and R. R. Sokal (1973).
  \emph{Numerical Taxonomy}.
  San Francisco: Freeman.

  Anderberg, M. R. (1973).
  \emph{Cluster Analysis for Applications}.
  Academic Press: New York.

  Gordon, A. D. (1999).
  \emph{Classification}. Second Edition.
  London: Chapman and Hall / CRC

  Murtagh, F. (1985).
  ``Multidimensional Clustering Algorithms'', in
  \emph{COMPSTAT Lectures 4}.
  Wuerzburg: Physica-Verlag
  (for algorithmic details of algorithms used).
}
\author{
  The \code{hclust} function is based an Algorithm
  contributed to STATLIB by F. Murtagh.
}
\seealso{
  \code{\link[mva]{hclust}} \code{\link[mva]{kmeans}}.
}
\examples{
library(amap)
data(USArrests)
hc <- hclust(dist(USArrests), "ave")
plot(hc)
plot(hc, hang = -1)

## Do the same with centroid clustering and squared Euclidean distance,
## cut the tree into ten clusters and reconstruct the upper part of the
## tree from the cluster centers.
hc <- hclust(dist(USArrests)^2, "cen")
memb <- cutree(hc, k = 10)
cent <- NULL
for(k in 1:10){
  cent <- rbind(cent, colMeans(USArrests[memb == k, , drop = FALSE]))
}
hc1 <- hclust(dist(cent)^2, method = "cen", members = table(memb))
opar <- par(mfrow = c(1, 2))
plot(hc,  labels = FALSE, hang = -1, main = "Original Tree")
plot(hc1, labels = FALSE, hang = -1, main = "Re-start from 10 clusters")
par(opar)
}
\keyword{multivariate}
\keyword{cluster}

\eof
\name{hcluster}
\title{Hierarchical Clustering}
\alias{hcluster}
\description{
  Hierarchical cluster analysis.
}
\usage{
hcluster(x, method = "euclidean", diag = FALSE, upper = FALSE,
         link = "complete", members = NULL)
}
\arguments{
  \item{x}{numeric matrix or (data frame).  Distances between the rows of
    \code{x} will be computed.}
  \item{method}{the distance measure to be used. This must be one of
    \code{"euclidean"}, \code{"maximum"}, \code{"manhattan"},
    \code{"canberra"} \code{"binary"} \code{"pearson"} or
    \code{"correlation"}.
    Any unambiguous substring can be given.}
  \item{diag}{logical value indicating whether the diagonal of the
    distance matrix should be printed by \code{print.dist}.}
  \item{upper}{logical value indicating whether the upper triangle of the
    distance matrix should be printed by \code{print.dist}.}
  \item{link}{the agglomeration method to be used. This should
    be (an unambiguous abbreviation of) one of
    \code{"ward"}, \code{"single"}, \code{"complete"},
    \code{"average"}, \code{"mcquitty"}, \code{"median"} or
    \code{"centroid"}.}
  \item{members}{\code{NULL} or a vector with length size of \code{d}.}
}
\value{
  An object of class \bold{hclust} which describes the
  tree produced by the clustering process.
  The object is a list with components:
  \item{merge}{an \eqn{n-1} by 2 matrix.
    Row \eqn{i} of \code{merge} describes the merging of clusters
    at step \eqn{i} of the clustering.
    If an element \eqn{j} in the row is negative,
    then observation \eqn{-j} was merged at this stage.
    If \eqn{j} is positive then the merge
    was with the cluster formed at the (earlier) stage \eqn{j}
    of the algorithm.
    Thus negative entries in \code{merge} indicate agglomerations
    of singletons, and positive entries indicate agglomerations
    of non-singletons.}

  \item{height}{a set of \eqn{n-1} non-decreasing real values.
    The clustering \emph{height}: that is, the value of
    the criterion associated with the clustering
    \code{method} for the particular agglomeration.}

  \item{order}{a vector giving the permutation of the original
    observations suitable for plotting, in the sense that a cluster
    plot using this ordering and matrix \code{merge} will not have
    crossings of the branches.}

  \item{labels}{labels for each of the objects being clustered.}

  \item{call}{the call which produced the result.}

  \item{method}{the cluster method that has been used.}

  \item{dist.method}{the distance that has been used to create \code{d}
    (only returned if the distance object has a \code{"method"}
    attribute).}

  There is a \code{\link{print}} and a \code{\link{plot}} method for
  \code{hclust} objects.
  The \code{plclust()} function is basically the same as the plot method,
  \code{plot.hclust}, primarily for back compatibility with S-plus. Its
  extra arguments are not yet implemented.
}
\details{
  This function is a mix of function \code{hclust} and function
   \code{dist}. \code{hcluster(x, method = "euclidean",link = "complete")
     = hclust(dist(x, method = "euclidean"),method = "complete"))}   
   It use twice less memory, as it doesn't store distance matrix.

   For more details, see documentation of \code{hclust} and \code{dist}.

}
\author{
  The \code{hcluster} function is based on C code
  by Antoine Lucas \url{http://genopole.toulouse.inra.fr/~lucas/amap}.
}
\seealso{
  \code{\link{dist}}, \code{\link{hclust}}, \code{\link[mva]{kmeans}}.
}
\examples{
library(mva)
data(USArrests)
hc <- hcluster(USArrests,link = "ave")
plot(hc)
plot(hc, hang = -1)

## Do the same with centroid clustering and squared Euclidean distance,
## cut the tree into ten clusters and reconstruct the upper part of the
## tree from the cluster centers.
hc <- hclust(dist(USArrests)^2, "cen")
memb <- cutree(hc, k = 10)
cent <- NULL
for(k in 1:10){
  cent <- rbind(cent, colMeans(USArrests[memb == k, , drop = FALSE]))
}
hc1 <- hclust(dist(cent)^2, method = "cen", members = table(memb))
opar <- par(mfrow = c(1, 2))
plot(hc,  labels = FALSE, hang = -1, main = "Original Tree")
plot(hc1, labels = FALSE, hang = -1, main = "Re-start from 10 clusters")
par(opar)
}
\keyword{multivariate}
\keyword{cluster}

\eof
\name{lubisch}
\alias{lubisch}
\title{Dataset Lubischew}
\usage{
data(lubisch)
}
\description{Donnes de Lubischew (1962) 74 insectes, 6 grandeurs morphologiques. 3 classes a priori}

\keyword{datasets}

\eof
\name{plot.acp}
\alias{plot.acp}
\alias{biplot.acp}
\alias{plot2.acp}

\title{Graphics for Principal component Analysis}
\description{Graphics for Principal component Analysis / Graphiques pour l'analyse en composantes principales, "comme Carlier"}
\usage{
plot.acp(x,i=1,j=2,text=TRUE,label='Composante ',col='darkblue',
main='ACP des individus',...)
biplot.acp(x,i=1,j=2,label='Composante ',col='darkblue',length=0.1,
main='ACP des variables',...)
plot2.acp(x,pourcent=FALSE,eigen=TRUE,label='Comp.',col='lightgrey',
main='Eboulis des valeurs propres',ylab='Valeurs propres')}

\arguments{
\item{x}{Result of acp / princomp}
\item{i}{X axis}
\item{j}{Y axis}
\item{text}{a logical value indicating whether we use text or points for plot}
\item{pourcent}{a logical value indicating whether we use pourcentage of 
values}
\item{eigen}{a logical value indicating whether we use eigen values or
standard deviation}
\item{label}{label for X and Y axis}
\item{col}{Color of plot}
\item{main}{Title of graphic}
\item{ylab}{Y label}
\item{length}{length of arrows}
\item{\dots}{cex, pch, and other options; see points.}
}




\value{
   Graphics: 

\code{plot.acp} PCA for lines / ACP des individus

\code{plot.acp} PCA for columns / ACP des variables

\code{plot2.acp} Eigen values diagram / Eboulis des valeurs propres
}



\examples{
data(lubisch)
lubisch <- lubisch[,-c(1,8)]
p <- acp(lubisch)
plot(p)
}
\keyword{multivariate}

\author{Antoine Lucas, \url{http://genopole.toulouse.inra.fr/~lucas/amap}}
\seealso{\link{acp},\link{acpgen}, \link[mva]{princomp}}

\eof
\name{VarRob}
\alias{varrob}
\alias{varrobsansC}

\title{Robust variance}
\description{Compute a robust variance}

\usage{
varrob(x,h,D=NULL,kernel="gaussien")
varrobsansC(x,h,D=NULL,kernel="gaussien")
}

\arguments{
\item{x}{Matrix  / data frame}
\item{h}{Scalar: bandwidth of the Kernel}
\item{kernel}{The kernel used. This must be one of '"gaussien"', 
'"quartic"', '"triweight"', '"epanechikov"' , 
'"cosinus"' or '"uniform"' } 
\item{D}{A product scalar matrix / une matrice de produit scalaire}
}

\details{

\code{U} compute robust variance. \eqn{U_n^{-1} = S_n^{-1} - 1/h V_n^{-1}}{1/Un
 = 1/Sn - 1 / (h Vn)}


\deqn{S_n=\frac{\sum_{i=1}^{n}K(||X_i||_{V_n^{-1}}/h)(X_i-\mu_n)(X_i-\mu_n)'}{\sum_{i=1}^nK(||X_i||_{V_n^{-1}}/h)}}{S: see latex doc}

with \eqn{\mu_n} estimator of the mean.

%\eqn{\delta=K(|| X_i-X_j||)} with K: a kernel.

\code{K} compute a kernel.

}


\value{
A matrix
}

\references{
  H. Caussinus, S. Hakam, A. Ruiz-Gazen
  Projections rvlatrices contrles: groupements et structures
  diverses.
  2002, to appear in Rev. Statist. Appli.
}


\keyword{multivariate}

\author{Antoine Lucas, \url{http://genopole.toulouse.inra.fr/~lucas/amap}}
\seealso{\link{acp} \link[mva]{princomp} }

\eof
